# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project attempts to adhere to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

***
## v0.1.1 (2021-07-07)

### Fix

- bug in `readme_location`

## v0.1.0 (2021-07-06)

- initial release
